To generate golden workflow yaml, for now please check the comments in [compiler_tests.py](../compiler_tests.py).

Once you generate a workflow yaml, please also test it with argo to make sure it is "golden".
